=======
Authors
=======

Development Lead
----------------
* Joern Weissenborn <joern.weissenborn@gmail.com>
* Joris Snellenburg <j.snellenburg@gmail.com>

Contributors
------------
* Sebastian Weigand <s.weigand.phy@gmail.com>

Special Thanks
--------------
* Stefan Schuetz
* Sergey P. Laptenok

Supervision
--------------
* **dr. Ivo H.M. van Stokkum** <i.h.m.van.stokkum@vu.nl> (`VU University profile <https://research.vu.nl/en/persons/ihm-van-stokkum>`_, `personal homepage <http://www.nat.vu.nl/~ivo/>`_)

Original publications
---------------------
1. Snellenburg JJ, Laptenok SP, Seger R, Mullen KM, van Stokkum IHM (2012). “Glotaran: A Java-Based Graphical User Interface for the R Package TIMP.” Journal of Statistical Software, 49(3), 1–22. URL http://www.jstatsoft.org/v49/i03/.
2. Mullen, Katharine, & Ivo H. M. van Stokkum. "TIMP: An R Package for Modeling Multi-way Spectroscopic Measurements." Journal of Statistical Software [Online], 18.3 (2007): 1 - 46. Web. 25 Jul. URL https://www.jstatsoft.org/article/view/v018i03
3. van Stokkum, IHM, Delmar S. Larsen, and Rienk van Grondelle. "Global and target analysis of time-resolved spectra." Biochimica et Biophysica Acta (BBA)-Bioenergetics 1657.2-3 (2004): 82-104. https://doi.org/10.1016/j.bbabio.2004.04.011
